@@ -593,7 +593,6 @@ class Casvlm1(AeroProblem):
         Vi_y = get(Vi_y)
         Vi_z = get(Vi_z)
 
-
         Vi = np.vstack((Vi_x, Vi_y, Vi_z)).T
 
         return Vi
@@ -712,4 +711,7 @@ class Casvlm1(AeroProblem):
                     points=streamline,
                 )
 
-        return fig.draw(show=show)
+        return fig.draw(
+            show=show,
+            colorbar_title=data_name
+        )
